state("Lake Haven - Chrysalis") {}

startup
{
    Assembly.Load(File.ReadAllBytes("Components/asl-help")).CreateInstance("Unity");
    vars.Helper.GameName = "Lake Haven - Chrysalis";
    vars.Helper.LoadSceneManager = true;
    vars.Helper.AlertLoadless();
}

init
{
    vars.Splits = new HashSet<string>();

    vars.Helper.TryLoad = (Func<dynamic, bool>)(mono =>
    {
        vars.Helper["nextRoom"] = mono.MakeString("SceneChangeManager", "Instance", "nextRoom");
        vars.Helper["igt"] = mono.Make<float>("SavedDataManager", "IGT");
        vars.Helper["autosplitHook"] = mono.Make<int>("SavedDataManager", "AutoSplitLevelHook");
        vars.Helper["isClockTimeCorrect"] = mono.Make<bool>("SavedDataManager", "globalLevelData", "isClockTimeCorrect");
        vars.Helper["gameTimeStarted"] = mono.Make<bool>("SavedDataManager", "globalSaveData", "gameTimeStarted");
        return true;
    });
}

update
{
    current.activeScene = vars.Helper.Scenes.Active.Name ?? old.activeScene;
    current.loadingScene = vars.Helper.Scenes.Loaded[0].Name ?? old.loadingScene;

    if (old.nextRoom != current.nextRoom)
    {
        vars.Log("NextRoom changed: " + old.nextRoom + " -> " + current.nextRoom);
    }

    if (old.autosplitHook != current.autosplitHook)
    {
        vars.Log("Room int changed: " + old.autosplitHook + " -> " + current.autosplitHook);
    }
}

start
{
    return current.activeScene == "FarmHouse_Exterior" && old.igt == 0f && current.igt > 0f;
}

reset
{
    var segName = timer.CurrentSplit.Name;
    if (segName != "End")
    {
        return current.activeScene == "MainMenu" || current.loadingScene == "WarningScreen";
    }
    else
    {
        return false;
    }
}

gameTime
{
    return TimeSpan.FromSeconds(current.igt);
}

split
{
    var segName = timer.CurrentSplit.Name;

    if (segName == "0")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_RanchArea")
        {
            return true;
        }
    }
    else if (segName == "Barn") 
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Barn")
        {
            return true;
        }
    }
    else if (segName == "2")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_RanchArea")
        {
            return true;
        }
    }
    else if (segName == "3")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "4")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Well")
        {
            return true;
        }
    }
    else if (segName == "5")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "House")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "6")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "7")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "8")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Storeroom")
        {
            return true;
        }
    }
    else if (segName == "9")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "10")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "Basement")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "WayToBasement")
        {
            return true;
        }
    }
    else if (segName == "12")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "13")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Well")
        {
            return true;
        }
    }
    else if (segName == "14")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "15")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "Clock Set")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "17")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Bathroom")
        {
            return true;
        }
    }
    else if (segName == "18")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "19")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Bedroom")
        {
            return true;
        }
    }
    else if (segName == "20")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "21")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Attic")
        {
            return true;
        }
    }
    else if (segName == "Safe")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "23")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "24")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "25")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Well")
        {
            return true;
        }
    }
    else if (segName == "26")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "27")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "28")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "Eleanor Skip")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Office")
        {
            return true;
        }
    }
    else if (segName == "30")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_2F")
        {
            return true;
        }
    }
    else if (segName == "31")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Farmhouse_Interior_1F")
        {
            return true;
        }
    }
    else if (segName == "32")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "33")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Well")
        {
            return true;
        }
    }
    else if (segName == "34")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Well2")
        {
            return true;
        }
    }
    else if (segName == "Big Head")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Well")
        {
            return true;
        }
    }
    else if (segName == "36")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "FarmHouse_Exterior")
        {
            return true;
        }
    }
    else if (segName == "37")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "WayToBasement")
        {
            return true;
        }
    }
    else if (segName == "38")
    {
        if (current.nextRoom != old.nextRoom && current.nextRoom == "Basement")
        {
            return true;
        }
    }
    else if (segName == "End")
    {
        return current.activeScene == "MainMenu" || current.loadingScene == "WarningScreen";
    }
}

isLoading
{
    return true;
}

onReset
{
    vars.Splits.Clear();
}

exit
{
    timer.IsGameTimePaused = true;
    vars.Splits.Clear();
}